@@ -1,5 +1,3 @@
-from __future__ import division, absolute_import, print_function
-
 import platform
 
 from distutils.unixccompiler import UnixCCompiler
@@ -17,9 +15,13 @@ class IntelCCompiler(UnixCCompiler):
 
     def __init__(self, verbose=0, dry_run=0, force=0):
         UnixCCompiler.__init__(self, verbose, dry_run, force)
+
+        v = self.get_version()
+        mpopt = 'openmp' if v and v < '15' else 'qopenmp'
         self.cc_exe = ('icc -fPIC -fp-model strict -O3 '
-                       '-fomit-frame-pointer -openmp')
+                       '-fomit-frame-pointer -{}').format(mpopt)
         compiler = self.cc_exe
+
         if platform.system() == 'Darwin':
             shared_flag = '-Wl,-undefined,dynamic_lookup'
         else:
@@ -53,9 +55,13 @@ class IntelEM64TCCompiler(UnixCCompiler):
 
     def __init__(self, verbose=0, dry_run=0, force=0):
         UnixCCompiler.__init__(self, verbose, dry_run, force)
+
+        v = self.get_version()
+        mpopt = 'openmp' if v and v < '15' else 'qopenmp'
         self.cc_exe = ('icc -m64 -fPIC -fp-model strict -O3 '
-                       '-fomit-frame-pointer -openmp')
+                       '-fomit-frame-pointer -{}').format(mpopt)
         compiler = self.cc_exe
+
         if platform.system() == 'Darwin':
             shared_flag = '-Wl,-undefined,dynamic_lookup'
         else:
